==> ginkgocadx_3.4.0.928.29%2Bdfsg.orig.tar.xz: ginkgocadx-3.4.0.928.29/src/cadxcore/main/gui/configuration/panelconfiguracionubicaciones.h <==
/*
 *  
 *  $Id: panelconfiguracionubicaciones.h $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/iconfiguracion.h>
#include "panelesconfiguracionginkgobase.h"
#include <string>
#include <vector>

namespace Ubicaciones {
	class UbicacionesGridTable;
}

namespace GNC {
	namespace GUI {

		class PanelConfiguracionUbicaciones: public PanelConfiguracionUbicacionesBase, public IPasoConfiguracion
		{
			public:
				PanelConfiguracionUbicaciones(wxWindow* pParent,IDialogoConfiguracion* pDialogo);
				~PanelConfiguracionUbicaciones();

				void Recargar();

				//region "Metodos de IPasoConfiguracion"
				wxWindow* GetPanel();

				std::string GetTitle();

				std::string GetCabecera();

				bool Validar();

				bool Guardar();
				//endregion

				//region "Helpers"
				void AutoSizeGrid();
				//endregion

			public:
				Ubicaciones::UbicacionesGridTable* m_pUbicacionesGridTable;


			protected:
				
				virtual void OnGridDClick( wxGridEvent& event );
				virtual void OnGridSelectionChanged(wxGridRangeSelectEvent& event);
				virtual void OnNuevoClick( wxCommandEvent& event );
				virtual void OnEditarClick( wxCommandEvent& event );
				virtual void OnEliminarClick( wxCommandEvent& event );
				virtual void OnHelpClick(wxMouseEvent &event);
				virtual void OnSize( wxSizeEvent& event );
		};
	}
}

==> ginkgocadx_3.7.1.1573.41%2Bdfsg.orig.tar.xz: ginkgocadx-3.7.1.1573.41/src/cadxcore/main/gui/configuration/panelconfiguracionubicaciones.h <==
/*
 *  
 *  $Id: panelconfiguracionubicaciones.h $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/iconfiguracion.h>
#include <api/ientorno.h>
#include "panelesconfiguracionginkgobase.h"
#include <string>
#include <vector>

namespace Ubicaciones {
	class UbicacionesGridTable;
}

namespace GNC {
	namespace GUI {

		class PanelConfiguracionUbicaciones: public PanelConfiguracionUbicacionesBase, public IPasoConfiguracion
		{
			public:
				PanelConfiguracionUbicaciones(wxWindow* pParent,IDialogoConfiguracion* pDialogo);
				~PanelConfiguracionUbicaciones();

				void Recargar();

				//region "Metodos de IPasoConfiguracion"
				wxWindow* GetPanel();

				std::string GetTitle();

				std::string GetCabecera();

				bool Validar();

				bool Guardar();
				//endregion

			public:
				wxObjectDataPtr<wxDataViewListStore> m_pModel;
				typedef GNC::GCS::IEntorno::MapaUbicaciones UbicationsMapType;
				UbicationsMapType m_Ubicaciones;

			protected:
				

				virtual void OnUbicationsDClick( wxDataViewEvent& event );
				virtual void OnUbicationsSelectionChanged( wxDataViewEvent& event);
				
				virtual void OnNuevoClick( wxCommandEvent& event );
				virtual void OnEditarClick( wxCommandEvent& event );
				virtual void OnEliminarClick( wxCommandEvent& event );
				virtual void OnHelpClick(wxMouseEvent &event);
				virtual void OnSize( wxSizeEvent& event );
		};
	}
}
